@@ -21,7 +21,7 @@ def generic_callback(response_bytes, payload, log_level, figsize):
     :param response_bytes: The header of the request received
     :param payload: Larger data
     :param log_level: logging level used in the callbacks
-    :param figsize: :class:`(int, int)` sets the figure size for showing any plots returned from VIP. The
+    :param figsize: :class:`(int, int)` sets the figure size for showing any plots returned from Virtualitics Explore. The
     resolution of the plots shown is controlled by the 'imsize' parameter in the function calls. The default is
     (8, 8).
     :return: Default None or pd.DataFrame containing column(s) of results
@@ -55,7 +55,7 @@ def generic_callback(response_bytes, payload, log_level, figsize):
             error = error.replace('\n', '').replace('<b>', '').replace('</b>', '').strip()
             exception_message = "Task '%s' failed because '%s'" % (task_type, error)
             if (task_type == "unknown") and (error == "(unknown reason)"):
-                raise exceptions.VipTaskUnknownExecutionException("The VIP task execution failed without providing a "
+                raise exceptions.VipTaskUnknownExecutionException("The Virtualitics Explore task execution failed without providing a "
                                                                   "reason. Please try running the command again. ")
             # also print 'Note' attribute if it exists
             if "Note" in failure:
@@ -72,19 +72,19 @@ def generic_callback(response_bytes, payload, log_level, figsize):
     else:
         # Priority given to authentication errors
         if response["AuthStatus"] != "Success":
-            # Raise and exception with the bubbled up error message from VIP
+            # Raise and exception with the bubbled up error message from Virtualitics Explore
             raise exceptions.AuthenticationException(response["Error"])
         if response["VersionStatus"] != "Success":
             if response["VersionStatusFailReason"] == "InvalidApiVersion":
                 raise exceptions.VersionMismatchException(
                     "pyVIP version (" + virtualitics.__version__ + ") is not supported by the installed version " +
-                    "of VIP (" + response["VIPVersion"] + "). VIP expecting pyVIP version (" +
+                    "of Virtualitics Explore (" + response["VIPVersion"] + "). Virtualitics Explore expecting pyVIP version (" +
                     response["ExpectedAPIVersion"] + ") or greater. Check 'Version' section in the documentation " +
                     "and update the appropriate tool.")
             elif response["VersionStatusFailReason"] == "InvalidVIPVersion":
                 raise exceptions.VersionMismatchException(
-                    "VIP version (" + response["VIPVersion"] + ") is not supported by the installed version of " +
-                    "pyVIP (" + virtualitics.__version__ + "). pyVIP expecting VIP version (" +
+                    "Virtualitics Explore version (" + response["VIPVersion"] + ") is not supported by the installed version of " +
+                    "pyVIP (" + virtualitics.__version__ + "). pyVIP expecting Virtualitics Explore version (" +
                     virtualitics.__latest_compatible_vip_version__ + ") or greater. Check 'Version' section in the " +
                     "documentation and update the appropriate tool.")
 
@@ -96,7 +96,7 @@ def _process_specific_task(task_response, payload, log_level, figsize):
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array
     :param log_level: logging level used in the callbacks
-    :param figsize: :class:`(int, int)` sets the figure size for showing any plots returned from VIP. The
+    :param figsize: :class:`(int, int)` sets the figure size for showing any plots returned from Virtualitics Explore. The
     resolution of the plots shown is controlled by the 'imsize' parameter in the function calls. The default is
     (8, 8).
     :return: Output of any specific task processing
@@ -195,7 +195,7 @@ def _plot_mapping_export_callback(task_response, payload, log_level):
 
     # Dimensions
     if "DimensionInfo" in task_response.keys():
-        # VIP 2021.2 and above packs dimension info in an array.
+        # Virtualitics Explore 2021.2 and above packs dimension info in an array.
         for d in task_response["DimensionInfo"]:
             try:
                 if d["Dimension"] == "X":
@@ -227,7 +227,7 @@ def _plot_mapping_export_callback(task_response, payload, log_level):
             except:
                 pass
     else:
-        # This the here to support older versions of VIP (< 2021.2 (1.9.0))
+        # This the here to support older versions of Virtualitics Explore (< 2021.2 (1.9.0))
         dimensionInfo = task_response
         if "X" in dimensionInfo.keys() and dimensionInfo["X"] is not None:
             try:
@@ -583,7 +583,7 @@ def _export_callback(task_response, payload, figsize):
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
-    :param figsize: :class:`(int, int)` sets the figure size for showing any plots returned from VIP. The
+    :param figsize: :class:`(int, int)` sets the figure size for showing any plots returned from Virtualitics Explore. The
     resolution of the plots shown is controlled by the 'imsize' parameter in the function calls. The default is
     (8, 8).
     :return: :class:`None`; displays the returned capture.
@@ -608,7 +608,7 @@ def _export_callback(task_response, payload, figsize):
 
 def _smart_mapping_callback(task_response, payload):
     """
-    Handles the VIP response for SmartMapping
+    Handles the Virtualitics Explore response for SmartMapping
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array. not used for smart mapping
@@ -635,7 +635,7 @@ def _smart_mapping_callback(task_response, payload):
 
 def _convert_column_callback(task_response, payload):
     """
-    Handles the VIP response for Filtering
+    Handles the Virtualitics Explore response for Filtering
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -646,7 +646,7 @@ def _convert_column_callback(task_response, payload):
 
 def _filter_callback(task_response, payload):
     """
-    Handles the VIP response for Filtering
+    Handles the Virtualitics Explore response for Filtering
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -657,7 +657,7 @@ def _filter_callback(task_response, payload):
 
 def _column_sync_callback(task_response, payload):
     """
-    Handles the VIP response for ColumnSync tasks
+    Handles the Virtualitics Explore response for ColumnSync tasks
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -667,7 +667,7 @@ def _column_sync_callback(task_response, payload):
 
 def _clustering_callback(task_response, payload):
     """
-    Handles the VIP response for Clustering
+    Handles the Virtualitics Explore response for Clustering
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -678,7 +678,7 @@ def _clustering_callback(task_response, payload):
 
 def _ad_callback(task_response, payload):
     """
-    Handles the VIP response for anomaly detection.
+    Handles the Virtualitics Explore response for anomaly detection.
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -688,7 +688,7 @@ def _ad_callback(task_response, payload):
 
 def _pca_callback(task_response, payload):
     """
-    Handles the VIP response for pca detection.
+    Handles the Virtualitics Explore response for pca detection.
 
     :param task_response: json object of the task response
     :param payload:  reference to the entire payload byte array.
@@ -698,7 +698,7 @@ def _pca_callback(task_response, payload):
 
 def _search_callback(task_response, payload):
     """
-    Handles the VIP response for search.
+    Handles the Virtualitics Explore response for search.
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -708,7 +708,7 @@ def _search_callback(task_response, payload):
 
 def _pagerank_callback(task_response, payload):
     """
-    Handles the VIP response for the pagerank callback
+    Handles the Virtualitics Explore response for the pagerank callback
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array.
@@ -719,7 +719,7 @@ def _pagerank_callback(task_response, payload):
 
 def _clustering_coefficient_callback(task_response, payload):
     """
-    Handles the VIP response for the clustering coefficient callback
+    Handles the Virtualitics Explore response for the clustering coefficient callback
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array
@@ -730,7 +730,7 @@ def _clustering_coefficient_callback(task_response, payload):
 
 def _graph_distance_callback(task_response, payload):
     """
-    Handles the VIP response for the graph distance callback
+    Handles the Virtualitics Explore response for the graph distance callback
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array
@@ -741,7 +741,7 @@ def _graph_distance_callback(task_response, payload):
 
 def _structure_callback(task_response, payload):
     """
-    Handles the VIP response for the clustering coefficient callback
+    Handles the Virtualitics Explore response for the clustering coefficient callback
 
     :param task_response: json object of the task response
     :param payload: reference to the entire payload byte array
@@ -751,7 +751,7 @@ def _structure_callback(task_response, payload):
 
 def _column_stats_callback(task_response, payload):
     """
-    Handles the VIP response for the Column Stats callback.
+    Handles the Virtualitics Explore response for the Column Stats callback.
     """
     column_stats = { "FeatureName" : task_response["FeatureName"],
                      "DataType" : task_response["DataType"],
@@ -878,14 +878,14 @@ def _get_network_callback(task_response, payload):
             data = json.loads(utils.decompress(data_bytes).decode())
             g = nx.Graph()
             for node_data in data["Nodes"]:
-                g.add_node(node_data["Name"], **node_data)
+                g.add_node(node_data["Node ID"], **node_data)
             for edge_data in data["Edges"]:
                 g.add_edge(edge_data["Source"], edge_data["Target"], weight=edge_data["Weight"])
             return g
         elif task_response["NetworkDataFormat"] == "Edgelist":
             return _ml_routine_callback(task_response, payload)
     else:
-        raise exceptions.VipTaskUnknownExecutionException("Failed to get network data from VIP. ")
+        raise exceptions.VipTaskUnknownExecutionException("Failed to get network data from Virtualitics Explore. ")
 
 def _create_custom_dashboard_callback(task_response, payload):
     # print(task_response)
@@ -1038,4 +1038,4 @@ def _extract_annotation_info(key, aInfo):
     if key in aInfo:
         return aInfo[key]
     
-    return None
\ No newline at end of file
+    return None
