@@ -103,7 +103,8 @@ HEATMAP_RADIUS_UNITS = {"kilometers": "Kilometers", "km": "Kilometers", "miles":
 STR_COL_DELIMETER = '\x01'
 EXPLAINABLE_AI_FUNCTION = {"identificationtree": "IdentificationTree", "id_tree" : "IdentificationTree", 
                             "categorybreakdown": "CategoryBreakdown", "categories": "CategoryBreakdown", 
-                            "relativeedgedensity": "RelativeEdgeDensity", "edges" : "RelativeEdgeDensity"}
+                            "relativeedgedensity": "RelativeEdgeDensity", "edges" : "RelativeEdgeDensity",
+                            "kolmogorovsmirnov" : "KolmogorovSmirnov", "kolmogorovsmirnov_test" : "KolmogorovSmirnov", "ks_test" : "KolmogorovSmirnov"}
 
 def case_insensitive_match(d: dict, val, var_name: str):
     """
@@ -191,7 +192,7 @@ def compress(data):
 def decompress(data):
     """
     Internal function to handle the decompression of data received from
-    VIP.
+    Virtualitics Explore.
     :param data: compressed bytearray. to be decompressed and deserialized.
     :returns bytes: decompressed bytes.
     """
@@ -276,7 +277,7 @@ def deserialize_column(data_type, data_bytes):
             raise exceptions.DeserializationException("The returned column was of an unsupported data type: " +
                                                       data_type)
     except Exception:
-        raise exceptions.DeserializationException("There was an error in deserializing the columns returned from VIP.")
+        raise exceptions.DeserializationException("There was an error in deserializing the columns returned from Virtualitics Explore.")
 
 
 def _deserialize_string_column(data):
@@ -291,7 +292,7 @@ def _deserialize_string_column(data):
         return escaped_string_list
     except Exception:
         raise exceptions.DeserializationException("There was an error in deserialized the column of strings returned "
-                                                  "from VIP. Contact Virtualitics at Support@Virtualitics.com")
+                                                  "from Virtualitics Explore. Contact Virtualitics at Support@Virtualitics.com")
 
 
 def _deserialize_double_column(data):
@@ -304,7 +305,7 @@ def _deserialize_double_column(data):
         return np.frombuffer(data, dtype=np.float64)
     except Exception:
         raise exceptions.DeserializationException("There was an error deserializing the column of dtype=np.float64 "
-                                                  "returned from VIP. Contact Virtualitics at Support@Virtualitics.com")
+                                                  "returned from Virtualitics Explore. Contact Virtualitics at Support@Virtualitics.com")
 
 
 def _deserialize_int_column(data):
@@ -316,7 +317,7 @@ def _deserialize_int_column(data):
     try:
         array = np.frombuffer(data, dtype=np.int32)
 
-        # VIP uses int.MinValue to represent missing values/deleted values for integer columns. As such, if int.MinValue
+        # Virtualitics Explore uses int.MinValue to represent missing values/deleted values for integer columns. As such, if int.MinValue
         # is detected in the returned column, we convert the dtype of the array to float64 to support np.nan
         min_val = np.iinfo(np.int32).min
         if min_val in array:
@@ -325,7 +326,7 @@ def _deserialize_int_column(data):
         return array
     except Exception:
         raise exceptions.DeserializationException("There was an error deserializing the column of dtype=np.int32 "
-                                                  "returned from VIP. Contact Virtualitics at Support@Virtualitics.com")
+                                                  "returned from Virtualitics Explore. Contact Virtualitics at Support@Virtualitics.com")
 
 
 def get_features(features):
